@@ -78,7 +78,9 @@ module Rack
             absolute_uri_for(token_endpoint),
             Util.compact_hash(params),
             headers
-          )
+          ) do |req|
+            yield req if block_given?
+          end
         end
       end
 
@@ -111,7 +113,9 @@ module Rack
             absolute_uri_for(revocation_endpoint),
             Util.compact_hash(params),
             headers
-          )
+          ) do |req|
+            yield req if block_given?
+          end
         end
       end
 
@@ -134,7 +138,7 @@ module Rack
         #  Using Array#extract_options! for backward compatibility.
         #  Until v1.0.5, the first argument was 'client_auth_method' in scalar.
         options = args.extract_options!
-        client_auth_method = args.first || options.delete(:client_auth_method).try(:to_sym) || :basic
+        client_auth_method = args.first || options.delete(:client_auth_method)&.to_sym || :basic
 
         case client_auth_method
         when :basic
@@ -176,8 +180,8 @@ module Rack
           params.merge!(
             client_id: identifier
           )
-          http_client.ssl_config.client_key = private_key
-          http_client.ssl_config.client_cert = certificate
+          http_client.ssl.client_key = private_key
+          http_client.ssl.client_cert = certificate
         else
           params.merge!(
             client_id: identifier,
@@ -209,26 +213,19 @@ module Rack
       end
 
       def handle_success_response(response)
-        token_hash = JSON.parse(response.body).with_indifferent_access
-        case (@forced_token_type || token_hash[:token_type]).try(:downcase)
+        token_hash = response.body.with_indifferent_access
+        case (@forced_token_type || token_hash[:token_type])&.downcase
         when 'bearer'
           AccessToken::Bearer.new(token_hash)
-        when 'mac'
-          AccessToken::MAC.new(token_hash)
-        when nil
-          AccessToken::Legacy.new(token_hash)
         else
           raise 'Unknown Token Type'
         end
-      rescue JSON::ParserError
-        # NOTE: Facebook support (They don't use JSON as token response)
-        AccessToken::Legacy.new Rack::Utils.parse_nested_query(response.body).with_indifferent_access
       end
 
       def handle_error_response(response)
-        error = JSON.parse(response.body).with_indifferent_access
+        error = response.body.with_indifferent_access
         raise Error.new(response.status, error)
-      rescue JSON::ParserError
+      rescue Faraday::ParsingError, NoMethodError
         raise Error.new(response.status, error: 'Unknown', error_description: response.body)
       end
     end
