@@ -8,7 +8,7 @@ module Rack
             @app = app
           end
 
-          def call(env)
+          def _call(env)
             prepare_oauth_env env
             @app.call env
           rescue Rack::OAuth2::Server::Abstract::Error => e
@@ -21,7 +21,7 @@ module Rack
             response_type = response_type_for(
               Server::Authorize::Request.new(env)
             ).new
-            response_type.call(env)
+            response_type._call(env)
             response_type.response.extend ResponseExt
             env[REQUEST]  = response_type.request
             env[RESPONSE] = response_type.response
